@@ -102,6 +102,9 @@ public:
    }
    complex_adaptor& operator = (const char* s)
    {
+      typedef typename mpl::front<unsigned_types>::type ui_type;
+      ui_type zero = 0u;
+
       using default_ops::eval_fpclassify;
 
       if (s && (*s == '('))
@@ -110,19 +113,25 @@ public:
          const char* p = ++s;
          while (*p && (*p != ',') && (*p != ')'))
             ++p;
-         part.assign(s + 1, p);
-         real_data() = part.c_str();
+         part.assign(s, p);
+         if(part.size())
+            real_data() = part.c_str();
+         else
+            real_data() = zero;
          s = p;
-         if (*p && (*p != '}'))
+         if (*p && (*p != ')'))
          {
             ++p;
-            while (*p && (*p != ',') && (*p != ')'))
+            while (*p && (*p != ')'))
                ++p;
             part.assign(s + 1, p);
          }
          else
             part.erase();
-         imag_data() = part.c_str();
+         if(part.size())
+            imag_data() = part.c_str();
+         else
+            imag_data() = zero;
 
          if (eval_fpclassify(imag_data()) == (int)FP_NAN)
          {
@@ -131,8 +140,6 @@ public:
       }
       else
       {
-         typedef typename mpl::front<unsigned_types>::type ui_type;
-         ui_type zero = 0u;
          real_data() = s;
          imag_data() = zero;
       }
